==> anjuta-2.91.5.0.tar.bz2: anjuta-2.91.5.0/plugins/am-project/ac-parser.h <==
/* A Bison parser, made by GNU Bison 2.4.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C
   
      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
   2009, 2010 Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     EOL = 259,
     SPACE = 260,
     HASH = 261,
     LEFT_PAREN = 262,
     RIGHT_PAREN = 263,
     LEFT_CURLY = 264,
     RIGHT_CURLY = 265,
     LEFT_BRACE = 266,
     RIGHT_BRACE = 267,
     EQUAL = 268,
     COMMA = 269,
     LOWER = 270,
     GREATER = 271,
     COMMENT = 256,
     NAME = 272,
     VARIABLE = 273,
     MACRO = 274,
     OPERATOR = 275,
     WORD = 276,
     JUNK = 277,
     START_SPACE_LIST = 278,
     DNL = 279,
     AC_MACRO_WITH_ARG = 280,
     AC_MACRO_WITHOUT_ARG = 281,
     PKG_CHECK_MODULES = 282,
     OBSOLETE_AC_OUTPUT = 283,
     AC_OUTPUT = 284,
     AC_CONFIG_FILES = 285,
     AC_SUBST = 286,
     AC_INIT = 287,
     EMPTY = 288,
     ARG = 289
   };
#endif
/* Tokens.  */
#define EOL 259
#define SPACE 260
#define HASH 261
#define LEFT_PAREN 262
#define RIGHT_PAREN 263
#define LEFT_CURLY 264
#define RIGHT_CURLY 265
#define LEFT_BRACE 266
#define RIGHT_BRACE 267
#define EQUAL 268
#define COMMA 269
#define LOWER 270
#define GREATER 271
#define COMMENT 256
#define NAME 272
#define VARIABLE 273
#define MACRO 274
#define OPERATOR 275
#define WORD 276
#define JUNK 277
#define START_SPACE_LIST 278
#define DNL 279
#define AC_MACRO_WITH_ARG 280
#define AC_MACRO_WITHOUT_ARG 281
#define PKG_CHECK_MODULES 282
#define OBSOLETE_AC_OUTPUT 283
#define AC_OUTPUT 284
#define AC_CONFIG_FILES 285
#define AC_SUBST 286
#define AC_INIT 287
#define EMPTY 288
#define ARG 289




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef int YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif



#if ! defined YYLTYPE && ! defined YYLTYPE_IS_DECLARED
typedef struct YYLTYPE
{
  int first_line;
  int first_column;
  int last_line;
  int last_column;
} YYLTYPE;
# define yyltype YYLTYPE /* obsolescent; will be withdrawn */
# define YYLTYPE_IS_DECLARED 1
# define YYLTYPE_IS_TRIVIAL 1
#endif



#ifndef YYPUSH_DECLS
#  define YYPUSH_DECLS
struct amp_ac_yypstate;
typedef struct amp_ac_yypstate amp_ac_yypstate;
enum { YYPUSH_MORE = 4 };
#if defined __STDC__ || defined __cplusplus
int amp_ac_yypush_parse (amp_ac_yypstate *yyps, int yypushed_char, YYSTYPE const *yypushed_val, YYLTYPE const *yypushed_loc, AmpAcScanner* scanner);
#else
int amp_ac_yypush_parse ();
#endif

#if defined __STDC__ || defined __cplusplus
amp_ac_yypstate * amp_ac_yypstate_new (void);
#else
amp_ac_yypstate * amp_ac_yypstate_new ();
#endif
#if defined __STDC__ || defined __cplusplus
void amp_ac_yypstate_delete (amp_ac_yypstate *yyps);
#else
void amp_ac_yypstate_delete ();
#endif
#endif

==> anjuta-3.2.2.tar.bz2: anjuta-3.2.2/plugins/am-project/ac-parser.h <==
/* A Bison parser, made by GNU Bison 2.5.  */

/* Bison interface for Yacc-like parsers in C
   
      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     EOL = 259,
     SPACE = 260,
     HASH = 261,
     LEFT_PAREN = 262,
     RIGHT_PAREN = 263,
     LEFT_CURLY = 264,
     RIGHT_CURLY = 265,
     LEFT_BRACE = 266,
     RIGHT_BRACE = 267,
     EQUAL = 268,
     COMMA = 269,
     LOWER = 270,
     GREATER = 271,
     COMMENT = 256,
     NAME = 272,
     VARIABLE = 273,
     MACRO = 274,
     OPERATOR = 275,
     WORD = 276,
     JUNK = 277,
     START_SPACE_LIST = 278,
     DNL = 279,
     AC_MACRO_WITH_ARG = 280,
     AC_MACRO_WITHOUT_ARG = 281,
     AC_ARG_ENABLE = 282,
     AC_C_CONST = 283,
     AC_CHECK_FUNCS = 284,
     AC_CHECK_HEADERS = 285,
     AC_CHECK_LIB = 286,
     AC_CHECK_PROG = 287,
     AC_CONFIG_FILES = 288,
     AC_CONFIG_HEADERS = 289,
     AC_CONFIG_MACRO_DIR = 290,
     AC_CONFIG_SRCDIR = 291,
     AC_EGREP_HEADER = 292,
     AC_EXEEXT = 293,
     AC_HEADER_STDC = 294,
     AC_INIT = 295,
     AC_OBJEXT = 296,
     AC_OUTPUT = 297,
     OBSOLETE_AC_OUTPUT = 298,
     AC_PREREQ = 299,
     AC_PROG_CC = 300,
     AC_PROG_CPP = 301,
     AC_PROG_CXX = 302,
     IT_PROG_INTLTOOL = 303,
     AC_PROG_LEX = 304,
     AC_PROG_RANLIB = 305,
     AC_PROG_YACC = 306,
     AC_SUBST = 307,
     AC_TYPE_SIZE_T = 308,
     AC_TYPE_OFF_T = 309,
     AM_INIT_AUTOMAKE = 310,
     AM_GLIB_GNU_GETTEXT = 311,
     AM_MAINTAINER_MODE = 312,
     AM_PROG_LIBTOOL = 313,
     LT_INIT = 314,
     LT_PREREQ = 315,
     PKG_CHECK_MODULES = 316,
     PKG_PROG_PKG_CONFIG = 317,
     EMPTY = 318,
     ARG = 319
   };
#endif
/* Tokens.  */
#define EOL 259
#define SPACE 260
#define HASH 261
#define LEFT_PAREN 262
#define RIGHT_PAREN 263
#define LEFT_CURLY 264
#define RIGHT_CURLY 265
#define LEFT_BRACE 266
#define RIGHT_BRACE 267
#define EQUAL 268
#define COMMA 269
#define LOWER 270
#define GREATER 271
#define COMMENT 256
#define NAME 272
#define VARIABLE 273
#define MACRO 274
#define OPERATOR 275
#define WORD 276
#define JUNK 277
#define START_SPACE_LIST 278
#define DNL 279
#define AC_MACRO_WITH_ARG 280
#define AC_MACRO_WITHOUT_ARG 281
#define AC_ARG_ENABLE 282
#define AC_C_CONST 283
#define AC_CHECK_FUNCS 284
#define AC_CHECK_HEADERS 285
#define AC_CHECK_LIB 286
#define AC_CHECK_PROG 287
#define AC_CONFIG_FILES 288
#define AC_CONFIG_HEADERS 289
#define AC_CONFIG_MACRO_DIR 290
#define AC_CONFIG_SRCDIR 291
#define AC_EGREP_HEADER 292
#define AC_EXEEXT 293
#define AC_HEADER_STDC 294
#define AC_INIT 295
#define AC_OBJEXT 296
#define AC_OUTPUT 297
#define OBSOLETE_AC_OUTPUT 298
#define AC_PREREQ 299
#define AC_PROG_CC 300
#define AC_PROG_CPP 301
#define AC_PROG_CXX 302
#define IT_PROG_INTLTOOL 303
#define AC_PROG_LEX 304
#define AC_PROG_RANLIB 305
#define AC_PROG_YACC 306
#define AC_SUBST 307
#define AC_TYPE_SIZE_T 308
#define AC_TYPE_OFF_T 309
#define AM_INIT_AUTOMAKE 310
#define AM_GLIB_GNU_GETTEXT 311
#define AM_MAINTAINER_MODE 312
#define AM_PROG_LIBTOOL 313
#define LT_INIT 314
#define LT_PREREQ 315
#define PKG_CHECK_MODULES 316
#define PKG_PROG_PKG_CONFIG 317
#define EMPTY 318
#define ARG 319




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef int YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif



#if ! defined YYLTYPE && ! defined YYLTYPE_IS_DECLARED
typedef struct YYLTYPE
{
  int first_line;
  int first_column;
  int last_line;
  int last_column;
} YYLTYPE;
# define yyltype YYLTYPE /* obsolescent; will be withdrawn */
# define YYLTYPE_IS_DECLARED 1
# define YYLTYPE_IS_TRIVIAL 1
#endif



#ifndef YYPUSH_DECLS
#  define YYPUSH_DECLS
struct amp_ac_yypstate;
typedef struct amp_ac_yypstate amp_ac_yypstate;
enum { YYPUSH_MORE = 4 };
#if defined __STDC__ || defined __cplusplus
int amp_ac_yypush_parse (amp_ac_yypstate *yyps, int yypushed_char, YYSTYPE const *yypushed_val, YYLTYPE const *yypushed_loc, AmpAcScanner* scanner);
#else
int amp_ac_yypush_parse ();
#endif

#if defined __STDC__ || defined __cplusplus
amp_ac_yypstate * amp_ac_yypstate_new (void);
#else
amp_ac_yypstate * amp_ac_yypstate_new ();
#endif
#if defined __STDC__ || defined __cplusplus
void amp_ac_yypstate_delete (amp_ac_yypstate *yyps);
#else
void amp_ac_yypstate_delete ();
#endif
#endif
